@@ -81,27 +81,29 @@ class GameConfig:
         sys.exit()
 
     def make_data_dir(self):
-        def find_data_dir(root):
+        def find_data_dir(root) -> (str, bool):
             data_dir = os.path.join(root, "fantomatic_data")
             return (data_dir, os.path.isdir(data_dir))
 
         sys_root = os.path.abspath(os.sep)
-        data_env = os.getenv("DATA_DIR")
+        exec_env = os.getenv("EXEC_DIR")
 
         data_dir_path = ""
 
-        for pth in (data_env, sys_root, self.app_dir):
+        for pth in (exec_env, sys_root, self.app_dir):
             if pth:
                 (data_dir, exists) = find_data_dir(pth)
                 if exists:
                     data_dir_path = data_dir
+                    break
 
         if not data_dir_path:
             data_dir_path = os.path.join(
-                data_env or self.app_dir, "fantomatic_data")
+                exec_env or self.app_dir, "fantomatic_data")
 
         if not os.path.isdir(data_dir_path):
             os.mkdir(data_dir_path)
+
         return data_dir_path
 
     def create_default_config_file(self):
